"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Vertex_1 = __importDefault(require("./Vertex"));
const IndexedModel_1 = __importDefault(require("./IndexedModel"));
function mapIndex(index, list) {
    if (index === null || index >= list.length)
        return null;
    return list[index];
}
function findIndexOrInsert(list, value, equals = (a, b) => a === b) {
    const foundIndex = list.findIndex((a => equals(a, value)));
    if (foundIndex >= 0)
        return foundIndex;
    return list.push(value) - 1;
}
function objectEquals(a, b) {
    return a.equals(b);
}
class Model extends Array {
    toIndexed() {
        const vertices = [];
        const normals = [];
        const uvs = [];
        const faces = this.map(face => face.map(vertex => ({
            vertex: vertex.position && findIndexOrInsert(vertices, vertex.position, objectEquals),
            normal: vertex.normal && findIndexOrInsert(normals, vertex.normal, objectEquals),
            uv: vertex.uv && findIndexOrInsert(normals, vertex.uv, objectEquals),
        })));
        return new IndexedModel_1.default(faces, vertices, normals, uvs);
    }
    static fromIndexed(indexed) {
        const { vertices, normals, uvs, } = indexed;
        const faces = indexed.faces.map(face => face.map(indexList => new Vertex_1.default(mapIndex(indexList.vertex, vertices), mapIndex(indexList.normal, normals), mapIndex(indexList.uv, uvs))));
        return new Model(...faces);
    }
}
exports.default = Model;
//# sourceMappingURL=Model.js.map